pari_jupyter: Jupyter kernel for PARI/GP
========================================

Description
-----------

A Jupyter kernel for PARI/GP

License
-------

GPL version 3 or later


Upstream Contact
----------------

-  https://github.com/jdemeyer/pari_jupyter
-  Jeroen Demeyer <J.Demeyer@UGent.be>

Dependencies
------------

-  Python (tested with version 2.7.14 and 3.6.1)
-  Jupyter 4
-  PARI version 2.8.0 or later
-  Readline (any version which works with PARI)
-  Optional: Cython version 0.25 or later
